<?php
function ope_form_box_init()
{
    $labels = array(
        'name' => OPE_FORM_BOX_NAME,
        'singular_name' => OPE_FORM_BOX_NAME,
        'menu_name' => OPE_FORM_BOX_NAME,
        'name_admin_bar' => OPE_FORM_BOX_NAME,
    );
    $args = array(
        'labels' => $labels,
        'public' => false,
        'publicly_queryable' => false,
        'show_ui' => true,
        'show_in_menu' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'ope_form_box'),
        'capability_type' => 'post',
        'has_archive' => true,
        'hierarchical' => false,
        'menu_position' => 1,
        'supports' => array('title'),
        'show_in_rest' => true,
        'taxonomies' => array('ope_form_box_category'),
        'exclude_from_search' => true,
    );
    register_post_type('ope_form_box', $args);
    $args = array(
        'labels' => array(
            'name' => OPE_FORM_BOX_CATEGORY_NAME ? OPE_FORM_BOX_CATEGORY_NAME : '',
        ),
        'hierarchical' => true,
        'public' => false,
        'publicly_queryable' => false,
        'show_ui' => true,
        'show_tagcloud' => false,
        'show_admin_column' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'ope_form_box_category'),
        'show_in_rest' => true,
    );
    register_taxonomy('ope_form_box_category', 'ope_form_box', $args);
}
add_action('init', 'ope_form_box_init');
add_action('restrict_manage_posts', 'ope_filter_taxonomy');
function ope_filter_taxonomy()
{
    global $typenow;
    $post_type = 'ope_form_box';
    $taxonomy = 'ope_form_box_category';
    if ($typenow == $post_type) {
        $selected = isset($_GET[$taxonomy]) ? $_GET[$taxonomy] : '';
        $info_taxonomy = get_taxonomy($taxonomy);
        wp_dropdown_categories(array(
            'show_option_all' => sprintf(__('Show all %s', 'textdomain'), $info_taxonomy->label),
            'taxonomy' => $taxonomy,
            'name' => $taxonomy,
            'orderby' => 'name',
            'selected' => $selected,
            'show_count' => true,
            'hide_empty' => true,
        ));
    }
    ;
}
add_filter('parse_query', 'ope_convert_term_in_query');
function ope_convert_term_in_query($query)
{
    global $pagenow;
    $post_type = 'ope_form_box';
    $taxonomy = 'ope_form_box_category';
    $qvs = &$query->query_vars;
    if ($pagenow == 'edit.php' && isset($qvs['post_type']) && $qvs['post_type'] == $post_type && isset($qvs[$taxonomy]) && is_numeric($qvs[$taxonomy]) && $qvs[$taxonomy] != 0) {
        $term = get_term_by('id', $qvs[$taxonomy], $taxonomy);
        $qvs[$taxonomy] = $term->slug;
    }
}
class OPE_Form_Meta_Box
{
    public function __construct()
    {
        if (is_admin()) {
            add_action('load-post.php', array($this, 'init_metabox'));
            add_action('load-post-new.php', array($this, 'init_metabox'));
        }
    }
    public function init_metabox()
    {
        add_action('add_meta_boxes', array($this, 'add_metabox'));
    }
    public function add_metabox()
    {
        add_meta_box(
            'ope_form_box_meta_box',
            'Email Data',
            array($this, 'render_metabox'),
            'ope_form_box',
            'advanced',
            'default'
        );
    }
    public function render_metabox($post)
    {
        $user_email_data = get_post_meta($post->ID, 'user_email_data', true);
        $user_http_data = get_post_meta($post->ID, 'user_http_data', true);
        $user_attachment_files = get_post_meta($post->ID, 'user_attachment_files', true);
        $user_attachment_images = get_post_meta($post->ID, 'user_attachment_images', true);
        ?>
<table>
    <?php
foreach ($user_email_data as $ued) {
            $value = $ued->value;
            preg_match('/(\<img.*?)*(data:image\/jpeg;base64)*(\>)/', $ued->value, $img_tag);
            if (!empty(@$img_tag)) {
                continue;
            }
            ?>
    <tr>
        <td><?php echo htmlspecialchars($ued->key); ?></td>
        <td><?php echo nl2br(htmlspecialchars($value)); ?></td>
    </tr>
    <?php
}
        if (!empty($user_attachment_images)) {
            foreach ($user_attachment_images as $uai) {
                ?>
    <tr>
        <td><?php echo htmlspecialchars($uai['name']); ?></td>
        <td><a href="<?php echo home_url() . $uai['url']; ?>" target="_blank"><img
                    src="<?php echo get_option('home') . $uai['url']; ?>" alt=""></a></td>
    </tr>
    <?php
}
        }
        if (!empty($user_attachment_files)) {
            foreach ($user_attachment_files as $uaf) {
                ?>
    <tr>
        <td><?php echo htmlspecialchars($uaf['name']); ?></td>
        <td><a href="<?php echo home_url() . $uaf['url']; ?>"
                target="_blank"><?php echo OPE_FORM_INBOX_ATTACHMENT_DOWNLOAD_TEXT; ?></a></td>
    </tr>
    <?php
}
        }
        ?>
</table>
<div class="download-email-data"><span id="export_to_pdf" data-title="<?php echo get_the_title($post->ID); ?>"
        data-id="<?php echo $post->ID; ?>"><i><?php echo OPE_FORM_CSV_EXPORT_BTN_TEXT; ?></i>
        <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 48 48">
            <path
                d="M11 40q-1.2 0-2.1-.9Q8 38.2 8 37v-7.15h3V37h26v-7.15h3V37q0 1.2-.9 2.1-.9.9-2.1.9Zm13-7.65-9.65-9.65 2.15-2.15 6 6V8h3v18.55l6-6 2.15 2.15Z" />
        </svg></span></div>
<table>
    <tr>
        <td>IP</td>
        <td><?php echo $user_http_data['ip']; ?></td>
    </tr>
    <tr>
        <td>Host</td>
        <td><?php echo $user_http_data['host']; ?></td>
    </tr>
    <tr>
        <td>URI</td>
        <td><?php echo $user_http_data['uri']; ?></td>
    </tr>
    <tr>
        <td>OS</td>
        <td><?php echo $user_http_data['user_os']; ?></td>
    </tr>
    <tr>
        <td>Agent</td>
        <td><?php echo $user_http_data['user_agent']; ?></td>
    </tr>
    <tr>
        <td>Click Action</td>
        <td><?php echo $user_http_data['client_click_action']; ?></td>
    </tr>
    <tr>
        <td>Multistep Count</td>
        <td><?php echo $user_http_data['client_multistep_count']; ?></td>
    </tr>
    <tr>
        <td>UA via javascript</td>
        <td><?php echo $user_http_data['client_UA']; ?></td>
    </tr>
    <tr>
        <td>Capcha Code</td>
        <td><?php echo $user_http_data['client_request_code']; ?></td>
    </tr>
    <tr>
        <td>Capcha Code REAL</td>
        <td><?php echo $user_http_data['request_code_REAL']; ?></td>
    </tr>
    <tr>
        <td>Current Page</td>
        <td><?php echo $user_http_data['current_page']; ?></td>
    </tr>
    <tr>
        <td>Client Language</td>
        <td><?php echo $user_http_data['client_language']; ?></td>
    </tr>
    <tr>
        <td>Client Logical Processors</td>
        <td><?php echo $user_http_data['client_logical_processors']; ?></td>
    </tr>
    <tr>
        <td>Client Screen Size</td>
        <td><?php echo $user_http_data['client_screen_size']; ?></td>
    </tr>
    <tr>
        <td>Client Click Position</td>
        <td><?php echo $user_http_data['client_click_position']; ?></td>
    </tr>
</table>
<?php
}
}
new OPE_Form_Meta_Box();
add_action('init', 'ope_form_remove_custom_type_from_search', 99);
function ope_form_remove_custom_type_from_search()
{
    global $wp_post_types;
    if (post_type_exists('ope_form_box')) {
        // exclude from search results
        $wp_post_types['ope_form_box']->exclude_from_search = true;
    }
}
if (OPE_FORM_REMOVE_ATTACHMENTS_WHEN_DELETE_POST == 1) {
    add_action('before_delete_post', 'opeform_delete_post');
    function opeform_delete_post($postid)
    {
        global $post_type;
        if ('ope_form_box' !== $post_type) {
            return;
        }
        $user_attachment_files = get_post_meta($postid, 'user_attachment_files', true);
        $user_attachment_images = get_post_meta($postid, 'user_attachment_images', true);
        if (!empty($user_attachment_images)) {
            foreach ($user_attachment_images as $uai) {
                $img = ABSPATH . $uai['url'];
                if (!unlink($img)) {
                    //
                } else {
                    //
                }
            }
        }
        if (!empty($user_attachment_files)) {
            foreach ($user_attachment_files as $uas) {
                $file = ABSPATH . $uas['url'];
                if (!unlink($file)) {
                    //
                } else {
                    //
                }
            }
        }
    }
}